FindQuery

Struct FindQuery 

#[non_exhaustive]
pub struct FindQuery { pub root: VirtualPath, pub name_contains: Option<String>, pub kind: Option<NodeKind>, pub min_logical_size: Option<u64>, pub max_logical_size: Option<u64>, pub modified_after_ms: Option<i64>, pub modified_before_ms: Option<i64>, pub attributes: BTreeMap<String, Value>, }
Metadata predicates for workspace-scoped node discovery.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
root: VirtualPath

The root beneath which matching nodes are considered.

name_contains: Option<String>

An optional case-sensitive substring required in the node name.

kind: Option<NodeKind>

An optional required node kind.

min_logical_size: Option<u64>

An optional inclusive lower bound on logical size.

max_logical_size: Option<u64>

An optional inclusive upper bound on logical size.

modified_after_ms: Option<i64>

An optional exclusive lower bound on modification time.

modified_before_ms: Option<i64>

An optional exclusive upper bound on modification time.

attributes: BTreeMap<String, Value>

Attribute key/value pairs that every match must contain.

Implementations

Source

impl FindQuery

pub fn root(self, root: VirtualPath) -> Self

Sets the root beneath which matching nodes are considered.

pub fn name_contains(self, name_contains: Option<String>) -> Self

Sets the optional case-sensitive node-name substring.

pub const fn kind(self, kind: Option<NodeKind>) -> Self

Sets the optional required node kind.

pub const fn min_logical_size(self, min_logical_size: Option<u64>) -> Self

Sets the optional inclusive lower bound on logical size.

pub const fn max_logical_size(self, max_logical_size: Option<u64>) -> Self

Sets the optional inclusive upper bound on logical size.

pub const fn modified_after_ms(self, modified_after_ms: Option<i64>) -> Self

Sets the optional exclusive lower modification-time bound.

pub const fn modified_before_ms(self, modified_before_ms: Option<i64>) -> Self

Sets the optional exclusive upper modification-time bound.

pub fn attributes(self, attributes: BTreeMap<String, Value>) -> Self

Sets the required attribute key/value pairs.