#[non_exhaustive]pub struct PageRequest {
pub cursor: Option<String>,
pub limit: u32,
}Expand description
Cursor pagination parameters shared by listing and discovery operations.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.cursor: Option<String>An opaque continuation cursor returned by a prior page.
limit: u32The maximum number of items requested from the backend.
Implementations