pub struct WriteSource { /* private fields */ }Expand description
A source of byte chunks consumed by a streamed write.
Implementations
Sourceimpl WriteSource
impl WriteSource
Sourcepub fn new(source: impl Stream<Item = FsResult<Bytes>> + Send + 'static) -> Self
pub fn new(source: impl Stream<Item = FsResult<Bytes>> + Send + 'static) -> Self
Wraps a sendable stream of byte chunks and filesystem errors.
Sourcepub fn from_bytes(bytes: impl Into<Bytes>) -> Self
pub fn from_bytes(bytes: impl Into<Bytes>) -> Self
Creates a one-chunk source from in-memory bytes.
Sourcepub fn into_stream(self) -> ByteStream
pub fn into_stream(self) -> ByteStream
Returns the wrapped stream.